← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/multiplayer-ui into lp:widelands

 

Toni Förster has proposed merging lp:~widelands-dev/widelands/multiplayer-ui into lp:widelands.

Commit message:
multiplayer-ui fine tuning

Requested reviews:
  Widelands Developers (widelands-dev)

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/multiplayer-ui/+merge/353523

Less free space and more room for the important parts. Pictures can be found in the Forum: 

https://wl.widelands.org/forum/post/25724/
-- 
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/multiplayer-ui into lp:widelands.
=== modified file 'src/ui_fsmenu/launch_mpg.cc'
--- src/wui/multiplayersetupgroup.cc	2018-06-08 17:14:28 +0000
+++ src/wui/multiplayersetupgroup.cc	2018-08-21 18:22:01 +0000
@@ -628,16 +628,16 @@
      settings_(settings),
      npsb(new NetworkPlayerSettingsBackend(settings_)),
      clientbox(this, 0, 0, UI::Box::Vertical),
-     playerbox(this, 0, 0, UI::Box::Vertical, w * 9 / 15, h, kPadding),
+     playerbox(this, 0, 0, UI::Box::Vertical, w * 36 / 53, h, kPadding),
      buth_(buth) {
-	clientbox.set_size(w / 3, h);
+	clientbox.set_size(w * 16 / 53, h);
 	clientbox.set_scrolling(true);
 
 	add(&clientbox, UI::Box::Resizing::kExpandBoth);
 	add(&playerbox);
 
 	// Playerbox
-	playerbox.set_size(w * 9 / 15, h);
+	playerbox.set_size(w * 36 / 53, h);
 	playerbox.add_space(0);
 	multi_player_player_groups.resize(kMaxPlayers);
 	for (PlayerSlot i = 0; i < multi_player_player_groups.size(); ++i) {


Follow ups
--- src/ui_fsmenu/launch_mpg.cc	2018-07-08 08:19:44 +0000
+++ src/ui_fsmenu/launch_mpg.cc	2018-08-21 18:22:01 +0000
@@ -105,7 +105,7 @@
      padding_(4),
      indent_(10),
      label_height_(20),
-     right_column_x_(get_w() * 37 / 50),
+     right_column_x_(get_w() * 57 / 80),
 
      // Buttons
      change_map_or_save_(this,
@@ -130,17 +130,17 @@
      // Text labels
      mapname_(this, right_column_x_, get_h() * 3 / 20, std::string()),
      clients_(this,
-              // (get_w() * 57 / 80) is the width of the MultiPlayerSetupGroup
-              get_w() / 50,
+              // the width of the MultiPlayerSetupGroup is (get_w() * 53 / 80)
+              get_w() * 3 / 80,
               get_h() / 10,
-              (get_w() * 57 / 80) / 3,
+              get_w() * 19 / 80,
               get_h() / 10,
               _("Clients"),
               UI::Align::kCenter),
      players_(this,
-              get_w() / 50 + (get_w() * 57 / 80) * 6 / 15,
+              get_w() /4,
               get_h() / 10,
-              (get_w() * 57 / 80) * 9 / 15,
+              get_w() * 9 / 20,
               get_h() / 10,
               _("Players"),
               UI::Align::kCenter),
@@ -155,13 +155,13 @@
                right_column_x_,
                get_h() * 2 / 10,
                butw_,
-               get_h() * 23 / 80 - 2 * label_height_,
+               get_h() * 23 / 80 - 1.6 * label_height_,
                UI::PanelStyle::kFsMenu),
      client_info_(this,
                   right_column_x_,
                   get_h() * 13 / 20 - 2 * label_height_,
                   butw_,
-                  2 * label_height_,
+                  get_h(),
                   UI::PanelStyle::kFsMenu),
      help_(nullptr),
 
@@ -185,12 +185,14 @@
 	players_.set_color(RGBColor(0, 255, 0));
 	map_.set_fontsize(fs_);
 	map_.set_color(RGBColor(0, 255, 0));
+	wincondition_type_.set_color(RGBColor(0, 255, 0));
 
 	mapname_.set_text(_("(no map)"));
 	map_info_.set_text(_("The host has not yet selected a map or saved game."));
 
 	mpsg_ = new MultiPlayerSetupGroup(
-	   this, get_w() / 50, change_map_or_save_.get_y(), get_w() * 57 / 80, get_h(), settings, buth_);
+	   this, get_w() * 3 / 80, change_map_or_save_.get_y(), get_w() * 53 / 80,
+	   get_h() * 17 / 30 - change_map_or_save_.get_y(), settings, buth_);
 
 	// If we are the host, open the map or save selection menu at startup
 	if (settings_->settings().usernum == 0 && settings_->settings().mapname.empty()) {
@@ -205,7 +207,7 @@
 	suggested_teams_box_ =
 	   new UI::SuggestedTeamsBox(this, right_column_x_, 0, UI::Box::Vertical, padding_, indent_,
 	                             get_w() - right_column_x_, 4 * label_height_);
-}
+ }
 
 FullscreenMenuLaunchMPG::~FullscreenMenuLaunchMPG() {
 	delete mpsg_;
@@ -223,8 +225,9 @@
  */
 void FullscreenMenuLaunchMPG::set_chat_provider(ChatProvider& chat) {
 	delete chat_;
-	chat_ = new GameChatPanel(this, get_w() / 50, get_h() * 13 / 20, get_w() * 57 / 80,
-	                          get_h() * 3 / 10, chat, UI::PanelStyle::kFsMenu);
+	chat_ = new GameChatPanel(this, get_w() * 3/ 80,
+			get_h() * 17 / 30 + 0.5 * label_height_, get_w() * 53 / 80,
+			get_h() * 11 / 30, chat, UI::PanelStyle::kFsMenu);
 }
 
 /**

=== modified file 'src/wui/multiplayersetupgroup.cc'